@@ -3,6 +3,7 @@ from .plotmath import (
     show,
     savefig,
     histogram,
+    plot_polygon,
     polygon,
     multiplot,
     gca,
@@ -16,6 +17,7 @@ __all__ = [
     "savefig",
     "show",
     "histogram",
+    "plot_polygon",
     "polygon",
     "multiplot",
     "gca",
